Module: Development

Defined in:
lib/templates/lib/development/seeder.rb

Overview

This file should ensure the existence of records required to run the application in development. The code here should be idempotent so that it can be executed at any point in development. The data can then be loaded with the bin/rails development:db:seed command.

Defined Under Namespace

Classes: Seeder